@@ -83,7 +83,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("xv", "lower", "upper", "
 #' @param barAlpha The alpha value of the bars in bar charts. Only applies if parameter \code{type} is \code{"bars"}. Default is 1
 #' @param barOutline If \code{TRUE}, each bar gets a colored outline. Only applies if parameter \code{type} is \code{bars}.
 #'          Default is \code{FALSE}.
-#' @param outlineColor The color of the bar outline. Only applies, if \code{barOutline} is set to \code{TRUE}.
+#' @param barOutlineColor The color of the bar outline. Only applies, if \code{barOutline} is set to \code{TRUE}.
 #'          Default is black.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
 #'          one line and when a line break is inserted into the title
@@ -106,6 +106,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("xv", "lower", "upper", "
 #' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
 #' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
 #' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default if \code{FALSE}.
+#' @param expand.grid If \code{TRUE}, the plot grid is expanded, i.e. there is a small margin between
+#'          axes and plotting region. Default is \code{FALSE}.
 #' @param showTickMarks Whether tick marks of axes should be shown or not
 #' @param showValueLabels Whether the value labels (mean differences) should be plotted 
 #'          to each dot or not.
@@ -191,7 +193,7 @@ sjp.aov1 <- function(depVar,
                     barWidth=0.5,
                     barAlpha=1,
                     barOutline=FALSE,
-                    outlineColor="black",
+                    barOutlineColor="black",
                     breakTitleAt=50, 
                     breakLabelsAt=12, 
                     gridBreaksAt=NULL,
@@ -202,6 +204,7 @@ sjp.aov1 <- function(depVar,
                     minorGridColor=NULL,
                     hideGrid.x=FALSE,
                     hideGrid.y=FALSE,
+                    expand.grid=FALSE,
                     showTickMarks=TRUE,
                     showValueLabels=TRUE, 
                     labelDigits=2,
@@ -246,6 +249,12 @@ sjp.aov1 <- function(depVar,
   if (type=="bar" || type=="b") {
     type <- "bars"
   }
+  if (expand.grid==TRUE) {
+    expand.grid <- waiver()
+  }
+  else {
+    expand.grid <- c(0,0)
+  }
   # --------------------------------------------------------
   # set geom colors
   # --------------------------------------------------------
@@ -281,7 +290,7 @@ sjp.aov1 <- function(depVar,
   # check whether bars should have an outline
   # --------------------------------------------------------
   if (!barOutline) {
-    outlineColor <- waiver()
+    barOutlineColor <- waiver()
   }  
   # check length of diagram title and split longer string at into new lines
   # every 50 chars
@@ -534,7 +543,7 @@ sjp.aov1 <- function(depVar,
   # bars, we don't want margins.
   # --------------------------------------------------------
   if (type=="bars") {
-    scaley <- scale_y_continuous(limits=c(lower_lim,upper_lim), expand=c(0,0), breaks=ticks, labels=ticks)    
+    scaley <- scale_y_continuous(limits=c(lower_lim,upper_lim), expand=expand.grid, breaks=ticks, labels=ticks)    
   }
   else {
     scaley <- scale_y_continuous(limits=c(lower_lim,upper_lim), breaks=ticks, labels=ticks)    
@@ -562,7 +571,7 @@ sjp.aov1 <- function(depVar,
       # stat-parameter indicates statistics
       # stat="bin": y-axis relates to count of variable
       # stat="identity": y-axis relates to value of variable
-      geom_bar(fill=df$geocol, stat="identity", position="identity", width=barWidth, colour=outlineColor, alpha=barAlpha) +
+      geom_bar(fill=df$geocol, stat="identity", position="identity", width=barWidth, colour=barOutlineColor, alpha=barAlpha) +
       # print value labels and p-values
       geom_text(aes(label=pv, y=means), colour=df$labcol, vjust=ifelse(df$means>=0, -1, 1), hjust=hlabj, size=valueLabelSize, alpha=valueLabelAlpha, show_guide=FALSE)
     if (hideErrorBars==FALSE) {
